#!/usr/bin/perl

##########################################################
#
# example1.pl
#
# This file contains a simple example of how the 
# subroutines in "FITSplot.pl" might be used to
# overplot colorscale and contours for total 
# intensity.
#
# Defaults set in the "FITSplot.pl" file can be
# modified by specifying the appropriate $plot
# variable here.  See the README file for details.
# Examples are the $plot{'image_corners'} and 
# $plot{'color_type'} variables which are set below.
#
# Finally, note that the subroutines in "FITSplot.pl" 
# are general, to control the details of pgplot (colors, 
# line styles, fonts, etc...) either change the defaults
# through the appropriate $plot variable or simply use
# the relevant pgplot command(s).
#
#  - Dan Homan, May 2002
#
##########################################################

require "FITSplot.pl";

###########################################################
#
# Setup some variables
#
##########################################################

my $Ifile = '3c120.ipol.gz';  # total intensity FITS file

my @conts = loglevs(0.002, 2);   # define an array of contour
                                      #   levels starting at 0.002 mJy
                                      #   in steps of x 2
                                      #   -- this subroutine is just
                                      #      for convience, contours
                                      #      can be simply defined like
                                      #      @conts = (1, 2, 3, 4);  

my $nlevs = @conts;                   # get length of the array for
                                      #   the number of contours 

#########################################################
#
# Open FITS files and slice the image arrays down to size
#
#########################################################

my $Iarray;       # define image arrays in advance

# define sub-region of interest in the image, default is full image,
#   format is [x1, x2, y1, y2]
$plot{'image_corners'} = [ 1.5, -9.0, -4.8, 2.2 ];  

$Iarray = Load_FITS($Ifile);     # Read in the FITS files, this returns
                                 #  $Iarray cut to 'image_corners'
 
##########################################################
#
# Begin the plot....
#
##########################################################

start_pgplot(0,'?',1,1);      # startup PGPLOT, arguments are the same
                              #  as for the pgbeg command in PGPLOT

begin_plot();                 # subroutine to begin current plot

$plot{'color_type'} = 'idl5'; # change from the default color scheme
                              #  to use 'idl5' scheme.  See colors.txt
                              #  for a complete list, or simply set
                              #  this to '' to get a list on the screen.

pgsitf(2);                    # set image transfer function 
                              #   0 = linear,  1 = log,  2 = square-root

colorscale($Iarray);               # Plot I-pol color image

contour($Iarray,\@conts,$nlevs);   # Plot I-pol contours 

plotbeam($Iarray);         # plot the beam figure for $Iarray image

finish_plot();             # subroutine to finish the current plot

pgend();                   # end pgplot 

exit;






