#!/usr/bin/perl

##########################################################
#
# example2.pl 
#
# This file contains a simple example of how the 
# subroutines in "FITSplot.pl" might be used to
# plot a polarization image with electric vector
# position angles.
#
# Defaults set in the "FITSplot.pl" file can be
# modified by specifying the appropriate $plot
# variable here.  See the README file for details.
# Examples are the $plot{'ticks_rotate'}, 
# $plot{'ticks_length'}, and $plot{'image_corners'} 
# variables which are set below.
#
# Although it is not obvious, this routine would work
# just as well with Stokes Q and U images.  They can
# be combined to form P and Chi by using the 'MakeP'
# subroutine in "FITSplot.pl", see README file for
# a description.
# 
# Finally, note that the subroutines in "FITSplot.pl" 
# are general, to control the details of pgplot (colors, 
# line styles, fonts, etc...) either change the defaults
# through the appropriate $plot variable or simply use
# the relevant pgplot command(s).
#
#  - Dan Homan, May 2002
#
##########################################################

require "FITSplot.pl";

##########################################################
#
# Setup some variables
#
##########################################################

my $Pfile = '3c120.ppol.gz';  # polarized intensity FITS file
my $Xfile = '3c120.pang.gz';  # polarization angle FITS file

$plot{'tick_rotate'} = -3;   # polarization angle correction (degrees)
$plot{'tick_length'} = 0.2;  # scale length of tick marks in plot units

my $pcut = 0.002;             # cutoff level for tick mark plotting

my @conts = loglevs(0.002,sqrt(2));   # define an array of contour
                                      #   levels starting at 0.002 Jy
                                      #   in steps of sqrt(2)
                                      #   -- this subroutine is just
                                      #      for convience, contours
                                      #      can be simply defined like
                                      #      @conts = (1, 2, 3, 4);  

my $nlevs = @conts;                   # get length of the array for
                                      #   the number of contours 

#########################################################
#
# Open FITS files and slice the image arrays down to size
#
#########################################################

my ($Parray, $Xarray);       # define image arrays in advance

# define sub-region of interest in the image, default is full image,
#   format is [x1, x2, y1, y2]
$plot{'image_corners'} = [ 1.5, -9.0, -4.8, 2.2 ];  

$Parray = Load_FITS($Pfile);     # Read in the FITS files, this returns
$Xarray = Load_FITS($Xfile);     #  arrays cut to 'image_corners'
 
##########################################################
#
# Begin the plot....
#
##########################################################

start_pgplot(0,'?',1,1);   # startup PGPLOT, arguments are the same
                           #  as for the pgbeg command in PGPLOT

begin_plot();              # subroutine to begin current plot

contour($Parray,\@conts,$nlevs);   # Plot P contours 

plotbeam($Parray);         # plot the beam figure for $Parray image

$plot{'tick_length'} = 0.2;      # set size scale of tick marks
ticks($Parray, $Xarray, $pcut);  # plot polarization ticks of uniform
                                 #   size.  Variable sized ticks can
                                 #   be plotted by specifying a 4th
                                 #   argument to the function which
                                 #   would be an array of lengths.

finish_plot();             # subroutine to finish the plot

pgend();                   # end pgplot 

exit;


