#!/usr/bin/perl

##########################################################
#
# example3.pl
#
# This file contains a simple example of how the 
# subroutines in "FITSplot.pl" might be used to
# overplot fractional polarization colorscale with
# total intensity contours.
#
# Defaults set in the "FITSplot.pl" file can be
# modified by specifying the appropriate $plot
# variable here.  See the README file for details.
# An example is the $plot{'image_corners'} variable
# which is set below.
#
# Finally, note that the subroutines in "FITSplot.pl" 
# are general, to control the details of pgplot (colors, 
# line styles, fonts, etc...) either change the defaults
# through the appropriate $plot variable or simply use
# the relevant pgplot command(s).
#
#  - Dan Homan, May 2002
#
##########################################################

require "FITSplot.pl";

###########################################################
#
# Setup some variables
#
##########################################################

my $Ifile = '3c120.ipol.gz';  # total intensity FITS file
my $Pfile = '3c120.ppol.gz';  # polarized intensity FITS file 

my $icut = 0.005;        # Levels at which to cut the I and P
my $pcut = 0.005;        #  images for making fractional polarization 

my @conts = loglevs(0.002,sqrt(2));   # define an array of contour
                                      #   levels starting at 0.002 mJy
                                      #   in steps of sqrt(2)
                                      #   -- this subroutine is just
                                      #      for convience, contours
                                      #      can be simply defined like
                                      #      @conts = (1, 2, 3, 4);  

my $nlevs = @conts;                   # get length of the array for
                                      #   the number of contours 

#########################################################
#
# Open FITS files and slice the image arrays down to size
#
#########################################################

my ($Iarray, $Parray, $Farray);       # define image arrays in advance

# define sub-region of interest in the image, default is full image,
#   format is [x1, x2, y1, y2]
$plot{'image_corners'} = [ 1.5, -9.0, -4.8, 2.2 ];  

$Iarray = Load_FITS($Ifile);     # Read in the FITS files, this returns
$Parray = Load_FITS($Pfile);     #  arrays cut to 'image_corners'
 
$Farray = MakeF($Iarray, $Parray, $icut, $pcut); # Make fractional pol.

##########################################################
#
# Begin the plot....
#
##########################################################

start_pgplot(0,'?',1,1);   # startup PGPLOT, arguments are the same
                           #  as for the pgbeg command in PGPLOT

begin_plot();              # subroutine to begin current plot

colorscale($Farray);       # Plot F-pol color image

contour($Iarray,\@conts,$nlevs);   # Plot I contours 

plotbeam($Iarray);         # plot the beam figure for $Iarray image

finish_plot();             # subroutine to finish the plot

pgend();                   # end pgplot 

exit;






